@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERACTIONREDIRECTTEST_H
-#define FILTERACTIONREDIRECTTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,10 +13,9 @@ class FilterActionRedirectTest : public QObject
     Q_OBJECT
 public:
     explicit FilterActionRedirectTest(QObject *parent = nullptr);
-    ~FilterActionRedirectTest();
+    ~FilterActionRedirectTest() override;
 private Q_SLOTS:
     void shouldBeEmpty();
     void shouldHaveRequiredPart();
 };
 
-#endif // FILTERACTIONREDIRECTTEST_H
