@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef FILTERACTIONMISSINGIDENTITYDIALOG_H
-#define FILTERACTIONMISSINGIDENTITYDIALOG_H
+#pragma once
 
 #include <QDialog>
 
@@ -20,7 +19,7 @@ class FilterActionMissingIdentityDialog : public QDialog
     Q_OBJECT
 public:
     explicit FilterActionMissingIdentityDialog(const QString &filtername, QWidget *parent = nullptr);
-    ~FilterActionMissingIdentityDialog();
+    ~FilterActionMissingIdentityDialog() override;
     Q_REQUIRED_RESULT int selectedIdentity() const;
 
 private:
@@ -30,4 +29,3 @@ private:
 };
 }
 
-#endif // FILTERACTIONMISSINGIDENTITYDIALOG_H
