@@ -1,28 +1,15 @@
 /*
 
-  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_FOLDERSELECTIONDIALOG_H
-#define MAILCOMMON_FOLDERSELECTIONDIALOG_H
+#pragma once
 
 #include "mailcommon_export.h"
 
-#include <Collection>
+#include <Akonadi/Collection>
 
 #include <QDialog>
 
@@ -30,7 +17,8 @@
 
 class KJob;
 
-namespace MailCommon {
+namespace MailCommon
+{
 /**
  * A dialog that lets the user select a folder.
  * TODO: Move most of this to Akonadi::CollectionDialog
@@ -82,8 +70,7 @@ protected:
 
 private:
     class FolderSelectionDialogPrivate;
-    FolderSelectionDialogPrivate *const d;
+    std::unique_ptr<FolderSelectionDialogPrivate> const d;
 };
 }
 
-#endif
