@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_TAGWIDGET_H
-#define MAILCOMMON_TAGWIDGET_H
+#pragma once
 
 #include "mailcommon_export.h"
 
@@ -28,7 +27,7 @@ class MAILCOMMON_EXPORT TagWidget : public QWidget
     Q_OBJECT
 public:
     explicit TagWidget(const QList<KActionCollection *> &actionCollections, QWidget *parent = nullptr);
-    ~TagWidget();
+    ~TagWidget() override;
 
     void recordTagSettings(MailCommon::Tag::Ptr tag);
 
@@ -58,8 +57,7 @@ Q_SIGNALS:
 
 private:
     void slotEmitChangeCheck();
-    TagWidgetPrivate *const d;
+    std::unique_ptr<TagWidgetPrivate> const d;
 };
 }
 
-#endif // MAILCOMMON_TAGWIDGET_H
